================
Matplotlib plots
================

The following plots use the matplotlib_ library directly.

.. toctree::
   :maxdepth: 2

   GalleryBarplots.rst
   GalleryPiePlots.rst
   GalleryLinePlots.rst
   GalleryHistograms.rst
   GalleryScatterPlots.rst
   GalleryVenn.rst
